Enum SendTimeoutError
pub enum SendTimeoutError<T> {
Timeout(T),
Closed(T),
}Expand description
Error returned by Sender::send_timeout.
Variants
Timeout(T)
The data could not be sent on the channel because the channel is full, and the timeout to send has elapsed.
Closed(T)
The receive half of the channel was explicitly closed or has been dropped.
Implementations
impl<T> SendTimeoutError<T>
impl<T> SendTimeoutError<T>
pub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume the SendTimeoutError, returning the unsent value.